from setuptools import setup


setup(name='onepara',
      version='0.2.0',
      description='deprecated',
      url='http://github.com/ulf1/scipy-psdm',
      author='Ulf Hamster',
      author_email='554c46@gmail.com',
      license='MIT',
      packages=['onepara'],
      install_requires=['setuptools>=40.0.0'],
      python_requires='>=3.6',
      zip_safe=False)
